@@ -15,13 +15,14 @@ fuehrt das Modul bei Datenaenderung aus.
 __all__ = [
     "RevPiModIO", "RevPiModIODriver", "RevPiModIOSelected", "run_plc",
     "RevPiNetIO", "RevPiNetIODriver", "RevPiNetIOSelected",
-    "Cycletools", "EventCallback"
+    "Cycletools", "EventCallback",
+    "AIO", "DI", "DO", "DIO",
 ]
 __author__ = "Sven Sager <akira@revpimodio.org>"
-__copyright__ = "Copyright (C) 2018 Sven Sager"
+__copyright__ = "Copyright (C) 2020 Sven Sager"
 __license__ = "LGPLv3"
 __name__ = "revpimodio2"
-__version__ = "2.5.1"
+__version__ = "2.5.3"
 
 # Global package values
 OFF = 0
@@ -33,6 +34,7 @@ BOTH = 33
 INP = 300
 OUT = 301
 MEM = 302
+PROCESS_IMAGE_SIZE = 4096
 
 
 class DeviceNotFoundError(Exception):
@@ -94,6 +96,7 @@ def consttostr(value) -> str:
 
 
 # Benötigte Klassen importieren
+from .pictory import AIO, DI, DO, DIO
 from .helper import Cycletools, EventCallback
 from .modio import RevPiModIO, RevPiModIODriver, RevPiModIOSelected, run_plc
 from .netio import RevPiNetIO, RevPiNetIODriver, RevPiNetIOSelected
