@@ -13,7 +13,7 @@ from .device import Device
 from .modio import RevPiModIO as _RevPiModIO
 
 __author__ = "Sven Sager"
-__copyright__ = "Copyright (C) 2018 Sven Sager"
+__copyright__ = "Copyright (C) 2020 Sven Sager"
 __license__ = "LGPLv3"
 
 # Synchronisierungsbefehl
@@ -336,14 +336,18 @@ class NetFH(Thread):
 
         with self.__socklock:
             # b CM ii ii 00000000 b = 16
-            self._slavesock.sendall(pack(
-                "=c2sHH8xc",
-                HEADER_START, b'FD', self.__int_buff, len(self.__by_buff), HEADER_STOP
-            ) + self.__by_buff)
-
-            # Puffer immer leeren
-            self.__int_buff = 0
-            self.__by_buff.clear()
+            try:
+                self._slavesock.sendall(pack(
+                    "=c2sHH8xc",
+                    HEADER_START, b'FD', self.__int_buff, len(self.__by_buff), HEADER_STOP
+                ) + self.__by_buff)
+            except Exception:
+                self.__flusherr = True
+                raise
+            finally:
+                # Puffer immer leeren
+                self.__int_buff = 0
+                self.__by_buff.clear()
 
             # Rückmeldebyte auswerten
             blockok = self._slavesock.recv(1)
@@ -483,9 +487,7 @@ class NetFH(Thread):
                 HEADER_START, b'DA', self.__position, length, HEADER_STOP
             ))
 
-            self.__position += length
-
-            buffer.clear()
+            net_buffer = b''
             while length > 0:
                 count = self._slavesock.recv_into(
                     self.__buff_block,
@@ -494,9 +496,13 @@ class NetFH(Thread):
                 if count == 0:
                     self.__sockerr.set()
                     raise IOError("read error on network")
-                buffer += self.__buff_block[:count]
+                net_buffer += self.__buff_block[:count]
                 length -= count
 
+            # We received the correct amount of bytes here
+            self.__position += length
+            buffer[:] = net_buffer
+
         return len(buffer)
 
     def readpictory(self) -> bytes:
